#ifndef NICONTROL_H
#define NICONTROL_H

#define MAX_DEPTH 10000

#include <OpenNI.h>
#include <QString>

class Frame;

class NIControl
{
public:
    enum DisplayMode {
        DISPLAY_MODE_OVERLAY=1,
        DISPLAY_MODE_DEPTH=2,
        DISPLAY_MODE_IMAGE=3,
        DISPLAY_MODE_IR=4
    };

    enum InputMode {
        FromFile,
        FromDevice
    };

    static NIControl * getInstance(QString oniFile="");
    ~NIControl();

    Frame* getFrame();
    inline void setDisplayMode(DisplayMode dm) { m_eViewState = dm; }
    inline void setZMin(int zMin) { this->zMin = zMin; }
    inline void setZMax(int zMax) { this->zMax = zMax; }
    void setup(QString filename="");


protected:
    NIControl(QString oniFile);
    void initOpenNI(QString oniFile);
    bool initCamera();
    bool stopCamera();
    inline bool isStarted() { return started; }
    void calculateHistogram(float *pHistogram, int histogramSize, const openni::VideoFrameRef &frame);


    friend class NiWidget;

protected:
    static NIControl * instance;
    InputMode inputMode;
    QString oniFile;
    bool started;

    Frame *frame;

    int depthWidth;
    int depthHeight;
    int zMin, zMax;


    openni::Status m_rc;
    openni::Device m_device;
    openni::VideoStream m_depthStream;
    openni::VideoStream m_colorStream;
    openni::VideoStream** m_streams;
    openni::VideoFrameRef m_depthFrame;
    openni::VideoFrameRef m_colorFrame;


    float               m_pDepthHist[MAX_DEPTH];
    char                m_strSampleName[ONI_MAX_STR];
    unsigned int            m_nTexMapX;
    unsigned int            m_nTexMapY;
    DisplayMode            m_eViewState;
    openni::RGB888Pixel*	m_pTexMap;
    openni::DepthPixel*     m_pDepthMap;

};


#endif // NICONTROL_H
