#include <QtGui>
#include <QtOpenGL>

#include <math.h>
#include <fstream>
#include <iostream>

#include "niwidget.h"
#include "util.h"
#include "nicontrol.h"
#include "frame.h"


NiWidget::NiWidget(QString oniFile, QWidget *parent) :
    QWidget(parent)
{
    filterTableSize=3;

    niControl = NIControl::getInstance(oniFile);

    const float alpha = 1.5f; //0.000642736f;
    filter = new GaussianFilter(float(filterTableSize), float(filterTableSize), alpha);
//    filter = new MitchellFilter(0.001f, 0.10f, filterTableSize, filterTableSize);

    QTimer *timer = new QTimer(this);
    timer->setSingleShot(false);
    connect(timer, SIGNAL(timeout()), this, SLOT(repaint()));
    timer->start(20);

    setAutoFillBackground(false);
}

NiWidget::~NiWidget()
{
    niControl->stopCamera();
}

void NiWidget::applyFilter()
{
    const int w = frame->width();
    const int h = frame->height();

    for(int y=0; y < h; ++y) {
        for(int x=0; x < w; ++x) {
            //Do something like this...
            //float v =  filter->evaluate(x,y);;
            //QRgb c = image.pixel(x,y);
            //image.setPixel(x,y, qRgb(qRed(c)*v, qGreen(c)*v, qBlue(c)*v) );
        }
    }

}

void NiWidget::drawFrame()
{
    QPainter painter(this);

    const int x = width()/2 - image.width()/2;
    const int y = height()/2 - image.height()/2;
    painter.drawImage(x,y, image);

    painter.end();
}

void NiWidget::paintEvent(QPaintEvent *event)
{

    if(!pause && niControl->isStarted()) {

        frame = niControl->getFrame();
        image = QImage((uchar *)frame->getTexture(), frame->width(), frame->height(), QImage::Format_RGB888);
        applyFilter();
        drawFrame();
    }
    Q_UNUSED(event);
}



void NiWidget::showRGB()
{
    niControl->setDisplayMode(NIControl::DISPLAY_MODE_IMAGE);
}

void NiWidget::showDepth()
{
    niControl->setDisplayMode(NIControl::DISPLAY_MODE_DEPTH);
}

void NiWidget::showOverlay()
{
    niControl->setDisplayMode(NIControl::DISPLAY_MODE_OVERLAY);
}

void NiWidget::captureFromONIFile()
{
    QString fileName = QFileDialog::getOpenFileName(this,
                                                    tr("Open ONI File"),
                                                    QString(),
                                                    tr("ONI (*.oni)"));
    if(!fileName.isEmpty()) {
        niControl->setup(fileName);

    }
}

void NiWidget::captureFromDevice()
{
    niControl->setup();
}


