/****************************************************************************
**
** Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** This file is part of the examples of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:BSD$
** You may use this file under the terms of the BSD license as follows:
**
** "Redistribution and use in source and binary forms, with or without
** modification, are permitted provided that the following conditions are
** met:
**   * Redistributions of source code must retain the above copyright
**     notice, this list of conditions and the following disclaimer.
**   * Redistributions in binary form must reproduce the above copyright
**     notice, this list of conditions and the following disclaimer in
**     the documentation and/or other materials provided with the
**     distribution.
**   * Neither the name of Nokia Corporation and its Subsidiary(-ies) nor
**     the names of its contributors may be used to endorse or promote
**     products derived from this software without specific prior written
**     permission.
**
** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
** "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
** LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
** A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
** OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
** SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
** LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
** DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
** THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
** (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
** OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE."
** $QT_END_LICENSE$
**
****************************************************************************/

#include <QtGui>
#include <QtOpenGL>

#include "niwidget.h"
#include "mainwindow.h"

MainWindow::MainWindow()
{

    centralWidget = new QWidget;
    setCentralWidget(centralWidget);

    niWidget = new NiWidget;
    niWidget->showRGB();

    niWidgetArea = new QScrollArea;
    niWidgetArea->setWidget(niWidget);
    niWidgetArea->setAlignment(Qt::AlignCenter);
    niWidgetArea->setWidgetResizable(true);
    niWidgetArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
    niWidgetArea->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
    niWidgetArea->setSizePolicy(QSizePolicy::Ignored, QSizePolicy::Ignored);
    niWidgetArea->setMinimumSize(80, 50);
    niWidgetArea->setPalette(QPalette(Qt::black));


    QAction *rgb = new QAction(QIcon(":/resources/images/RGB.png"), "RGB Mode", this);
    rgb->setCheckable(true);
    connect(rgb, SIGNAL(triggered()), niWidget, SLOT(showRGB()));

    QAction *depth = new QAction(QIcon(":/resources/images/head.png"), "Depthmap Mode", this);
    connect(depth, SIGNAL(triggered()), niWidget, SLOT(showDepth()));
    depth->setCheckable(true);

    QAction *overlay = new QAction(QIcon(":/resources/images/head-rgb.png"), "Overlay Mode", this);
    connect(overlay, SIGNAL(triggered()), niWidget, SLOT(showOverlay()));
    overlay->setCheckable(true);

    QAction *fromFile = new QAction(QIcon(":/resources/images/open2.png"), "Capture from ONI file", this);
    connect(fromFile, SIGNAL(triggered()), niWidget, SLOT(captureFromONIFile()));
    fromFile->setCheckable(true);

    QAction *fromDevice = new QAction(QIcon(":resources/images/kinect.png"), "Capture from kinect", this);
    connect(fromDevice, SIGNAL(triggered()), niWidget, SLOT(captureFromDevice()));
    fromDevice->setCheckable(true);


    QActionGroup *modeGroup = new QActionGroup(this);
    modeGroup->addAction(rgb);
    modeGroup->addAction(depth);
    modeGroup->addAction(overlay);
    rgb->setChecked(true);

    QActionGroup *captureGroup = new QActionGroup(this);
    captureGroup->addAction(fromFile);
    captureGroup->addAction(fromDevice);
    fromDevice->setChecked(true);

    QToolBar *controls = new QToolBar;
    controls->setOrientation(Qt::Horizontal);
    controls->setBackgroundRole(QPalette::Foreground);
    controls->setAutoFillBackground(true);
    controls->setIconSize(QSize(48,48));

    controls->addAction(rgb);
    controls->addAction(depth);
    controls->addAction(overlay);
    controls->addSeparator();
    controls->addAction(fromFile);
    controls->addAction(fromDevice);


    QGridLayout *centralLayout = new QGridLayout;
    centralLayout->addWidget(controls, 0, 0);
    centralLayout->addWidget(niWidgetArea, 1, 0);

    centralWidget->setLayout(centralLayout);

    setWindowTitle(tr("VG RGB-D"));
    resize(1024, 768);

}
